/* Generated by dbus-binding-tool; do not edit! */

#include <glib/gtypes.h>
#include <glib/gerror.h>
#include <dbus/dbus-glib.h>

G_BEGIN_DECLS

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_ConnectionManager
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_ConnectionManager

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_ConnectionManager_request_connection (DBusGProxy *proxy, const char * IN_protocol, const GHashTable* IN_parameters, char ** OUT_arg2, char** OUT_arg3, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestConnection", error, G_TYPE_STRING, IN_protocol, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE), IN_parameters, G_TYPE_INVALID, G_TYPE_STRING, OUT_arg2, DBUS_TYPE_G_OBJECT_PATH, OUT_arg3, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_ConnectionManager_request_connection_reply) (DBusGProxy *proxy, char * OUT_arg2, char *OUT_arg3, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_ConnectionManager_request_connection_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char * OUT_arg2;
  char* OUT_arg3;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRING, &OUT_arg2, DBUS_TYPE_G_OBJECT_PATH, &OUT_arg3, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_ConnectionManager_request_connection_reply)data->cb) (proxy, OUT_arg2, OUT_arg3, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_ConnectionManager_request_connection_async (DBusGProxy *proxy, const char * IN_protocol, const GHashTable* IN_parameters, org_freedesktop_Telepathy_ConnectionManager_request_connection_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestConnection", org_freedesktop_Telepathy_ConnectionManager_request_connection_async_callback, stuff, g_free, G_TYPE_STRING, IN_protocol, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE), IN_parameters, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_ConnectionManager_get_parameters (DBusGProxy *proxy, const char * IN_protocol, GPtrArray** OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetParameters", error, G_TYPE_STRING, IN_protocol, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_VALUE, G_TYPE_INVALID)), OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_ConnectionManager_get_parameters_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_ConnectionManager_get_parameters_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_VALUE, G_TYPE_INVALID)), &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_ConnectionManager_get_parameters_reply)data->cb) (proxy, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_ConnectionManager_get_parameters_async (DBusGProxy *proxy, const char * IN_protocol, org_freedesktop_Telepathy_ConnectionManager_get_parameters_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetParameters", org_freedesktop_Telepathy_ConnectionManager_get_parameters_async_callback, stuff, g_free, G_TYPE_STRING, IN_protocol, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_ConnectionManager_list_protocols (DBusGProxy *proxy, char *** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "ListProtocols", error, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_ConnectionManager_list_protocols_reply) (DBusGProxy *proxy, char * *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_ConnectionManager_list_protocols_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_ConnectionManager_list_protocols_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_ConnectionManager_list_protocols_async (DBusGProxy *proxy, org_freedesktop_Telepathy_ConnectionManager_list_protocols_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ListProtocols", org_freedesktop_Telepathy_ConnectionManager_list_protocols_async_callback, stuff, g_free, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_ConnectionManager */

G_END_DECLS
