( cd usr/lib ; rm -rf libtapioca-client-glib-0.14.so )
( cd usr/lib ; ln -sf libtapioca-client-glib-0.14.so.0.0.0 libtapioca-client-glib-0.14.so )
( cd usr/lib ; rm -rf libtapioca-core-glib-0.14.so.0 )
( cd usr/lib ; ln -sf libtapioca-core-glib-0.14.so.0.0.0 libtapioca-core-glib-0.14.so.0 )
( cd usr/lib ; rm -rf libtapioca-core-glib-0.14.so )
( cd usr/lib ; ln -sf libtapioca-core-glib-0.14.so.0.0.0 libtapioca-core-glib-0.14.so )
( cd usr/lib ; rm -rf libtapioca-base-glib-0.14.so.0 )
( cd usr/lib ; ln -sf libtapioca-base-glib-0.14.so.0.0.0 libtapioca-base-glib-0.14.so.0 )
( cd usr/lib ; rm -rf libtapioca-client-glib-0.14.so.0 )
( cd usr/lib ; ln -sf libtapioca-client-glib-0.14.so.0.0.0 libtapioca-client-glib-0.14.so.0 )
( cd usr/lib ; rm -rf libtapioca-base-glib-0.14.so )
( cd usr/lib ; ln -sf libtapioca-base-glib-0.14.so.0.0.0 libtapioca-base-glib-0.14.so )
