/* Generated by dbus-binding-tool; do not edit! */

#include <glib/gtypes.h>
#include <glib/gerror.h>
#include <dbus/dbus-glib.h>

G_BEGIN_DECLS

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_connect (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "Connect", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_connect_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_connect_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_connect_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_connect_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_connect_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "Connect", org_freedesktop_Telepathy_Connection_connect_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_disconnect (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "Disconnect", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_disconnect_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_disconnect_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_disconnect_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_disconnect_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_disconnect_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "Disconnect", org_freedesktop_Telepathy_Connection_disconnect_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_get_interfaces (DBusGProxy *proxy, char *** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetInterfaces", error, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_get_interfaces_reply) (DBusGProxy *proxy, char * *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_get_interfaces_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_get_interfaces_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_get_interfaces_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_get_interfaces_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetInterfaces", org_freedesktop_Telepathy_Connection_get_interfaces_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_get_protocol (DBusGProxy *proxy, char ** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetProtocol", error, G_TYPE_INVALID, G_TYPE_STRING, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_get_protocol_reply) (DBusGProxy *proxy, char * OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_get_protocol_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char * OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRING, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_get_protocol_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_get_protocol_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_get_protocol_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetProtocol", org_freedesktop_Telepathy_Connection_get_protocol_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_get_self_handle (DBusGProxy *proxy, guint* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetSelfHandle", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_get_self_handle_reply) (DBusGProxy *proxy, guint OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_get_self_handle_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_get_self_handle_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_get_self_handle_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_get_self_handle_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetSelfHandle", org_freedesktop_Telepathy_Connection_get_self_handle_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_get_status (DBusGProxy *proxy, guint* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetStatus", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_get_status_reply) (DBusGProxy *proxy, guint OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_get_status_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_get_status_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_get_status_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_get_status_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetStatus", org_freedesktop_Telepathy_Connection_get_status_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_hold_handles (DBusGProxy *proxy, const guint IN_handle_type, const GArray* IN_handle, GError **error)

{
  return dbus_g_proxy_call (proxy, "HoldHandles", error, G_TYPE_UINT, IN_handle_type, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handle, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_hold_handles_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_hold_handles_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_hold_handles_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_hold_handles_async (DBusGProxy *proxy, const guint IN_handle_type, const GArray* IN_handle, org_freedesktop_Telepathy_Connection_hold_handles_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "HoldHandles", org_freedesktop_Telepathy_Connection_hold_handles_async_callback, stuff, g_free, G_TYPE_UINT, IN_handle_type, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handle, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_inspect_handles (DBusGProxy *proxy, const guint IN_handle_type, const GArray* IN_handle, char *** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "InspectHandles", error, G_TYPE_UINT, IN_handle_type, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handle, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_inspect_handles_reply) (DBusGProxy *proxy, char * *OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_inspect_handles_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_inspect_handles_reply)data->cb) (proxy, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_inspect_handles_async (DBusGProxy *proxy, const guint IN_handle_type, const GArray* IN_handle, org_freedesktop_Telepathy_Connection_inspect_handles_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "InspectHandles", org_freedesktop_Telepathy_Connection_inspect_handles_async_callback, stuff, g_free, G_TYPE_UINT, IN_handle_type, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handle, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_list_channels (DBusGProxy *proxy, GPtrArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "ListChannels", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_list_channels_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_list_channels_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_list_channels_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_list_channels_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_list_channels_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ListChannels", org_freedesktop_Telepathy_Connection_list_channels_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_release_handles (DBusGProxy *proxy, const guint IN_handle_type, const GArray* IN_handle, GError **error)

{
  return dbus_g_proxy_call (proxy, "ReleaseHandles", error, G_TYPE_UINT, IN_handle_type, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handle, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_release_handles_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_release_handles_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_release_handles_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_release_handles_async (DBusGProxy *proxy, const guint IN_handle_type, const GArray* IN_handle, org_freedesktop_Telepathy_Connection_release_handles_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ReleaseHandles", org_freedesktop_Telepathy_Connection_release_handles_async_callback, stuff, g_free, G_TYPE_UINT, IN_handle_type, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handle, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_request_channel (DBusGProxy *proxy, const char * IN_type, const guint IN_handle_type, const guint IN_handle, const gboolean IN_suppress_handler, char** OUT_arg4, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestChannel", error, G_TYPE_STRING, IN_type, G_TYPE_UINT, IN_handle_type, G_TYPE_UINT, IN_handle, G_TYPE_BOOLEAN, IN_suppress_handler, G_TYPE_INVALID, DBUS_TYPE_G_OBJECT_PATH, OUT_arg4, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_request_channel_reply) (DBusGProxy *proxy, char *OUT_arg4, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_request_channel_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char* OUT_arg4;
  dbus_g_proxy_end_call (proxy, call, &error, DBUS_TYPE_G_OBJECT_PATH, &OUT_arg4, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_request_channel_reply)data->cb) (proxy, OUT_arg4, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_request_channel_async (DBusGProxy *proxy, const char * IN_type, const guint IN_handle_type, const guint IN_handle, const gboolean IN_suppress_handler, org_freedesktop_Telepathy_Connection_request_channel_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestChannel", org_freedesktop_Telepathy_Connection_request_channel_async_callback, stuff, g_free, G_TYPE_STRING, IN_type, G_TYPE_UINT, IN_handle_type, G_TYPE_UINT, IN_handle, G_TYPE_BOOLEAN, IN_suppress_handler, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_request_handles (DBusGProxy *proxy, const guint IN_handle_type, const char ** IN_names, GArray** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestHandles", error, G_TYPE_UINT, IN_handle_type, G_TYPE_STRV, IN_names, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_request_handles_reply) (DBusGProxy *proxy, GArray *OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_request_handles_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_request_handles_reply)data->cb) (proxy, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_request_handles_async (DBusGProxy *proxy, const guint IN_handle_type, const char ** IN_names, org_freedesktop_Telepathy_Connection_request_handles_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestHandles", org_freedesktop_Telepathy_Connection_request_handles_async_callback, stuff, g_free, G_TYPE_UINT, IN_handle_type, G_TYPE_STRV, IN_names, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Aliasing
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Aliasing

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags (DBusGProxy *proxy, guint* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetAliasFlags", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags_reply) (DBusGProxy *proxy, guint OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetAliasFlags", org_freedesktop_Telepathy_Connection_Interface_Aliasing_get_alias_flags_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases (DBusGProxy *proxy, const GArray* IN_contacts, char *** OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestAliases", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases_reply) (DBusGProxy *proxy, char * *OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases_reply)data->cb) (proxy, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases_async (DBusGProxy *proxy, const GArray* IN_contacts, org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestAliases", org_freedesktop_Telepathy_Connection_Interface_Aliasing_request_aliases_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases (DBusGProxy *proxy, const GHashTable* IN_aliases, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetAliases", error, dbus_g_type_get_map ("GHashTable", G_TYPE_UINT, G_TYPE_STRING), IN_aliases, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases_async (DBusGProxy *proxy, const GHashTable* IN_aliases, org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetAliases", org_freedesktop_Telepathy_Connection_Interface_Aliasing_set_aliases_async_callback, stuff, g_free, dbus_g_type_get_map ("GHashTable", G_TYPE_UINT, G_TYPE_STRING), IN_aliases, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Aliasing */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Avatars
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Avatars

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements (DBusGProxy *proxy, char *** OUT_arg0, guint* OUT_arg1, guint* OUT_arg2, guint* OUT_arg3, guint* OUT_arg4, guint* OUT_arg5, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetAvatarRequirements", error, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg0, G_TYPE_UINT, OUT_arg1, G_TYPE_UINT, OUT_arg2, G_TYPE_UINT, OUT_arg3, G_TYPE_UINT, OUT_arg4, G_TYPE_UINT, OUT_arg5, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements_reply) (DBusGProxy *proxy, char * *OUT_arg0, guint OUT_arg1, guint OUT_arg2, guint OUT_arg3, guint OUT_arg4, guint OUT_arg5, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg0;
  guint OUT_arg1;
  guint OUT_arg2;
  guint OUT_arg3;
  guint OUT_arg4;
  guint OUT_arg5;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg0, G_TYPE_UINT, &OUT_arg1, G_TYPE_UINT, &OUT_arg2, G_TYPE_UINT, &OUT_arg3, G_TYPE_UINT, &OUT_arg4, G_TYPE_UINT, &OUT_arg5, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements_reply)data->cb) (proxy, OUT_arg0, OUT_arg1, OUT_arg2, OUT_arg3, OUT_arg4, OUT_arg5, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetAvatarRequirements", org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_requirements_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens (DBusGProxy *proxy, const GArray* IN_contacts, char *** OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetAvatarTokens", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens_reply) (DBusGProxy *proxy, char * *OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens_reply)data->cb) (proxy, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens_async (DBusGProxy *proxy, const GArray* IN_contacts, org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetAvatarTokens", org_freedesktop_Telepathy_Connection_Interface_Avatars_get_avatar_tokens_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar (DBusGProxy *proxy, const guint IN_contact, GArray** OUT_arg1, char ** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestAvatar", error, G_TYPE_UINT, IN_contact, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), OUT_arg1, G_TYPE_STRING, OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar_reply) (DBusGProxy *proxy, GArray *OUT_arg1, char * OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg1;
  char * OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), &OUT_arg1, G_TYPE_STRING, &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar_reply)data->cb) (proxy, OUT_arg1, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar_async (DBusGProxy *proxy, const guint IN_contact, org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestAvatar", org_freedesktop_Telepathy_Connection_Interface_Avatars_request_avatar_async_callback, stuff, g_free, G_TYPE_UINT, IN_contact, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar (DBusGProxy *proxy, const GArray* IN_avatar, const char * IN_mime_type, char ** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetAvatar", error, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), IN_avatar, G_TYPE_STRING, IN_mime_type, G_TYPE_INVALID, G_TYPE_STRING, OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar_reply) (DBusGProxy *proxy, char * OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char * OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRING, &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar_reply)data->cb) (proxy, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar_async (DBusGProxy *proxy, const GArray* IN_avatar, const char * IN_mime_type, org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetAvatar", org_freedesktop_Telepathy_Connection_Interface_Avatars_set_avatar_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), IN_avatar, G_TYPE_STRING, IN_mime_type, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Avatars */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Capabilities
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Capabilities

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities (DBusGProxy *proxy, const GPtrArray* IN_add, const char ** IN_remove, GPtrArray** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "AdvertiseCapabilities", error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INVALID)), IN_add, G_TYPE_STRV, IN_remove, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INVALID)), OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INVALID)), &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities_reply)data->cb) (proxy, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities_async (DBusGProxy *proxy, const GPtrArray* IN_add, const char ** IN_remove, org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "AdvertiseCapabilities", org_freedesktop_Telepathy_Connection_Interface_Capabilities_advertise_capabilities_async_callback, stuff, g_free, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INVALID)), IN_add, G_TYPE_STRV, IN_remove, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities (DBusGProxy *proxy, const GArray* IN_handles, GPtrArray** OUT_handles, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetCapabilities", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handles, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), OUT_handles, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities_reply) (DBusGProxy *proxy, GPtrArray *OUT_handles, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_handles;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), &OUT_handles, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities_reply)data->cb) (proxy, OUT_handles, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities_async (DBusGProxy *proxy, const GArray* IN_handles, org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetCapabilities", org_freedesktop_Telepathy_Connection_Interface_Capabilities_get_capabilities_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handles, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Capabilities */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_ContactInfo
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_ContactInfo

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info (DBusGProxy *proxy, const guint IN_contact, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestContactInfo", error, G_TYPE_UINT, IN_contact, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info_async (DBusGProxy *proxy, const guint IN_contact, org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestContactInfo", org_freedesktop_Telepathy_Connection_Interface_ContactInfo_request_contact_info_async_callback, stuff, g_free, G_TYPE_UINT, IN_contact, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_ContactInfo */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Forwarding
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Forwarding

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle (DBusGProxy *proxy, guint* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetForwardingHandle", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle_reply) (DBusGProxy *proxy, guint OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetForwardingHandle", org_freedesktop_Telepathy_Connection_Interface_Forwarding_get_forwarding_handle_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle (DBusGProxy *proxy, const guint IN_forward_to, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetForwardingHandle", error, G_TYPE_UINT, IN_forward_to, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle_async (DBusGProxy *proxy, const guint IN_forward_to, org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetForwardingHandle", org_freedesktop_Telepathy_Connection_Interface_Forwarding_set_forwarding_handle_async_callback, stuff, g_free, G_TYPE_UINT, IN_forward_to, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Forwarding */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Presence
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Presence

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_add_status (DBusGProxy *proxy, const char * IN_status, const GHashTable* IN_parms, GError **error)

{
  return dbus_g_proxy_call (proxy, "AddStatus", error, G_TYPE_STRING, IN_status, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE), IN_parms, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_add_status_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_add_status_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_add_status_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_add_status_async (DBusGProxy *proxy, const char * IN_status, const GHashTable* IN_parms, org_freedesktop_Telepathy_Connection_Interface_Presence_add_status_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "AddStatus", org_freedesktop_Telepathy_Connection_Interface_Presence_add_status_async_callback, stuff, g_free, G_TYPE_STRING, IN_status, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE), IN_parms, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "ClearStatus", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ClearStatus", org_freedesktop_Telepathy_Connection_Interface_Presence_clear_status_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses (DBusGProxy *proxy, GHashTable** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetStatuses", error, G_TYPE_INVALID, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), G_TYPE_INVALID)), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses_reply) (DBusGProxy *proxy, GHashTable *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GHashTable* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), G_TYPE_INVALID)), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetStatuses", org_freedesktop_Telepathy_Connection_Interface_Presence_get_statuses_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status (DBusGProxy *proxy, const char * IN_status, GError **error)

{
  return dbus_g_proxy_call (proxy, "RemoveStatus", error, G_TYPE_STRING, IN_status, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status_async (DBusGProxy *proxy, const char * IN_status, org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RemoveStatus", org_freedesktop_Telepathy_Connection_Interface_Presence_remove_status_async_callback, stuff, g_free, G_TYPE_STRING, IN_status, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence (DBusGProxy *proxy, const GArray* IN_contacts, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestPresence", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence_async (DBusGProxy *proxy, const GArray* IN_contacts, org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestPresence", org_freedesktop_Telepathy_Connection_Interface_Presence_request_presence_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time (DBusGProxy *proxy, const guint IN_time, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetLastActivityTime", error, G_TYPE_UINT, IN_time, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time_async (DBusGProxy *proxy, const guint IN_time, org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetLastActivityTime", org_freedesktop_Telepathy_Connection_Interface_Presence_set_last_activity_time_async_callback, stuff, g_free, G_TYPE_UINT, IN_time, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Connection_Interface_Presence_set_status (DBusGProxy *proxy, const GHashTable* IN_statuses, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetStatus", error, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE)), IN_statuses, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Connection_Interface_Presence_set_status_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Connection_Interface_Presence_set_status_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Connection_Interface_Presence_set_status_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Connection_Interface_Presence_set_status_async (DBusGProxy *proxy, const GHashTable* IN_statuses, org_freedesktop_Telepathy_Connection_Interface_Presence_set_status_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetStatus", org_freedesktop_Telepathy_Connection_Interface_Presence_set_status_async_callback, stuff, g_free, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE)), IN_statuses, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Connection_Interface_Presence */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Properties
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Properties

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Properties_get_properties (DBusGProxy *proxy, const GArray* IN_properties, GPtrArray** OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetProperties", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_properties, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_VALUE, G_TYPE_INVALID)), OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Properties_get_properties_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Properties_get_properties_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_VALUE, G_TYPE_INVALID)), &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Properties_get_properties_reply)data->cb) (proxy, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Properties_get_properties_async (DBusGProxy *proxy, const GArray* IN_properties, org_freedesktop_Telepathy_Properties_get_properties_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetProperties", org_freedesktop_Telepathy_Properties_get_properties_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_properties, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Properties_list_properties (DBusGProxy *proxy, GPtrArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "ListProperties", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INVALID)), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Properties_list_properties_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Properties_list_properties_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INVALID)), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Properties_list_properties_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Properties_list_properties_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Properties_list_properties_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ListProperties", org_freedesktop_Telepathy_Properties_list_properties_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Properties_set_properties (DBusGProxy *proxy, const GPtrArray* IN_properties, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetProperties", error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_VALUE, G_TYPE_INVALID)), IN_properties, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Properties_set_properties_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Properties_set_properties_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Properties_set_properties_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Properties_set_properties_async (DBusGProxy *proxy, const GPtrArray* IN_properties, org_freedesktop_Telepathy_Properties_set_properties_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetProperties", org_freedesktop_Telepathy_Properties_set_properties_async_callback, stuff, g_free, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_VALUE, G_TYPE_INVALID)), IN_properties, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Properties */

G_END_DECLS
