/*
 * Copyright (C) 2006 INdT.
 * @author  Luiz Augusto von Dentz <luiz.dentz@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TPA_IFACES_H__
#define __TPA_IFACES_H__

G_BEGIN_DECLS

#define DBUS_ALIASING_IFACE \
    "org.freedesktop.Telepathy.Connection.Interface.Aliasing"
#define DBUS_AVATARS_IFACE \
    "org.freedesktop.Telepathy.Connection.Interface.Avatars"
#define DBUS_CAPABILITIES_IFACE \
    "org.freedesktop.Telepathy.Connection.Interface.Capabilities"
#define DBUS_CHANNEL_IFACE \
    "org.freedesktop.Telepathy.Channel"
#define DBUS_CHANNEL_PATH \
    "/org/freedesktop/Telepathy/Channel"
#define DBUS_CONNECTION_IFACE \
    "org.freedesktop.Telepathy.Connection"
#define DBUS_CONNECTION_PATH \
    "/org/freedesktop/Telepathy/Connection"
#define DBUS_CONNECTION_MANAGER_IFACE \
    "org.freedesktop.Telepathy.ConnectionManager"
#define DBUS_CONNECTION_MANAGER_PATH \
    "/org/freedesktop/Telepathy/ConnectionManager"
#define DBUS_CONTACT_INFO_IFACE \
    "org.freedesktop.Telepathy.Connection.Interface.ContactList"
#define DBUS_FORWARDING_IFACE \
    "org.freedesktop.Telepathy.Connection.Interface.Forwarding"
#define DBUS_GROUP_IFACE \
    "org.freedesktop.Telepathy.Channel.Interface.Group"
#define DBUS_ICE_SIGNALLING_IFACE \
    "org.freedesktop.Telepathy.Channel.Interface.IceSignalling"
#define DBUS_PRESENCE_IFACE \
    "org.freedesktop.Telepathy.Connection.Interface.Presence"
#define DBUS_PROPERTIES_IFACE \
    "org.freedesktop.Telepathy.Properties"
#define DBUS_TYPE_CONTACTLIST_IFACE \
    "org.freedesktop.Telepathy.Channel.Type.ContactList"
#define DBUS_TYPE_CONTACTSEARCH_IFACE \
    "org.freedesktop.Telepathy.Channel.Type.ContactList"
#define DBUS_TYPE_STREAMEDMEDIA_IFACE \
    "org.freedesktop.Telepathy.Channel.Type.StreamedMedia"
#define DBUS_TYPE_ROOMLIST_IFACE \
    "org.freedesktop.Telepathy.Channel.Type.RoomList"
#define DBUS_TYPE_TEXT_IFACE \
    "org.freedesktop.Telepathy.Channel.Type.Text"

G_END_DECLS

#endif /* #ifndef __TPA_IFACES_H__ */
