/*
 * Tapioca library
 * Copyright (C) 2006 INdT.
 * @author  Abner Jose de Faria Silva <abner.silva@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TPA_UTILS_H__
#define __TPA_UTILS_H__

#include "tpa-enums.h"

#define TPA_OBJ_UNREF(obj) if((obj)!=NULL){g_object_unref(obj);obj=NULL;}

TpaChannelType           tpa_utils_get_channel_type_as_enum        (const gchar *interface);
const gchar             *tpa_utils_get_channel_type_as_string      (TpaChannelType type);
TpaConnectionHandleType  tpa_utils_get_handle_type_by_channel_type (TpaChannelType type);

#endif /* #ifndef __TPA_UTILS_H__*/
