/* Generated by dbus-binding-tool; do not edit! */

#include <glib/gtypes.h>
#include <glib/gerror.h>
#include <dbus/dbus-glib.h>

G_BEGIN_DECLS

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_close (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "Close", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_close_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_close_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_close_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_close_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_close_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "Close", org_freedesktop_Telepathy_Channel_close_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_get_channel_type (DBusGProxy *proxy, char ** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetChannelType", error, G_TYPE_INVALID, G_TYPE_STRING, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_get_channel_type_reply) (DBusGProxy *proxy, char * OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_get_channel_type_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char * OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRING, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_get_channel_type_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_get_channel_type_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_get_channel_type_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetChannelType", org_freedesktop_Telepathy_Channel_get_channel_type_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_get_handle (DBusGProxy *proxy, guint* OUT_arg0, guint* OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetHandle", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_UINT, OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_get_handle_reply) (DBusGProxy *proxy, guint OUT_arg0, guint OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_get_handle_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  guint OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_UINT, &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_get_handle_reply)data->cb) (proxy, OUT_arg0, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_get_handle_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_get_handle_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetHandle", org_freedesktop_Telepathy_Channel_get_handle_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_get_interfaces (DBusGProxy *proxy, char *** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetInterfaces", error, G_TYPE_INVALID, G_TYPE_STRV, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_get_interfaces_reply) (DBusGProxy *proxy, char * *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_get_interfaces_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  char ** OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_STRV, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_get_interfaces_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_get_interfaces_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_get_interfaces_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetInterfaces", org_freedesktop_Telepathy_Channel_get_interfaces_async_callback, stuff, g_free, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_Text
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_Text

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages (DBusGProxy *proxy, const GArray* IN_ids, GError **error)

{
  return dbus_g_proxy_call (proxy, "AcknowledgePendingMessages", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_ids, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages_async (DBusGProxy *proxy, const GArray* IN_ids, org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "AcknowledgePendingMessages", org_freedesktop_Telepathy_Channel_Type_Text_acknowledge_pending_messages_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_ids, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_Text_get_message_types (DBusGProxy *proxy, GArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetMessageTypes", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_Text_get_message_types_reply) (DBusGProxy *proxy, GArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_Text_get_message_types_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_Text_get_message_types_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_Text_get_message_types_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Type_Text_get_message_types_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetMessageTypes", org_freedesktop_Telepathy_Channel_Type_Text_get_message_types_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages (DBusGProxy *proxy, const gboolean IN_clear, GPtrArray** OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "ListPendingMessages", error, G_TYPE_BOOLEAN, IN_clear, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_INVALID)), OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_INVALID)), &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages_reply)data->cb) (proxy, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages_async (DBusGProxy *proxy, const gboolean IN_clear, org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ListPendingMessages", org_freedesktop_Telepathy_Channel_Type_Text_list_pending_messages_async_callback, stuff, g_free, G_TYPE_BOOLEAN, IN_clear, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_Text_send (DBusGProxy *proxy, const guint IN_type, const char * IN_text, GError **error)

{
  return dbus_g_proxy_call (proxy, "Send", error, G_TYPE_UINT, IN_type, G_TYPE_STRING, IN_text, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_Text_send_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_Text_send_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_Text_send_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_Text_send_async (DBusGProxy *proxy, const guint IN_type, const char * IN_text, org_freedesktop_Telepathy_Channel_Type_Text_send_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "Send", org_freedesktop_Telepathy_Channel_Type_Text_send_async_callback, stuff, g_free, G_TYPE_UINT, IN_type, G_TYPE_STRING, IN_text, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_Text */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_Group
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_Group

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_add_members (DBusGProxy *proxy, const GArray* IN_contacts, const char * IN_message, GError **error)

{
  return dbus_g_proxy_call (proxy, "AddMembers", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_STRING, IN_message, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_add_members_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_add_members_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_add_members_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_add_members_async (DBusGProxy *proxy, const GArray* IN_contacts, const char * IN_message, org_freedesktop_Telepathy_Channel_Interface_Group_add_members_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "AddMembers", org_freedesktop_Telepathy_Channel_Interface_Group_add_members_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_STRING, IN_message, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_remove_members (DBusGProxy *proxy, const GArray* IN_contacts, const char * IN_message, GError **error)

{
  return dbus_g_proxy_call (proxy, "RemoveMembers", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_STRING, IN_message, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_remove_members_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_remove_members_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_remove_members_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_remove_members_async (DBusGProxy *proxy, const GArray* IN_contacts, const char * IN_message, org_freedesktop_Telepathy_Channel_Interface_Group_remove_members_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RemoveMembers", org_freedesktop_Telepathy_Channel_Interface_Group_remove_members_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_contacts, G_TYPE_STRING, IN_message, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members (DBusGProxy *proxy, GArray** OUT_arg0, GArray** OUT_arg1, GArray** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetAllMembers", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg0, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg1, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members_reply) (DBusGProxy *proxy, GArray *OUT_arg0, GArray *OUT_arg1, GArray *OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg0;
  GArray* OUT_arg1;
  GArray* OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg0, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg1, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members_reply)data->cb) (proxy, OUT_arg0, OUT_arg1, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetAllMembers", org_freedesktop_Telepathy_Channel_Interface_Group_get_all_members_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags (DBusGProxy *proxy, guint* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetGroupFlags", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags_reply) (DBusGProxy *proxy, guint OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetGroupFlags", org_freedesktop_Telepathy_Channel_Interface_Group_get_group_flags_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners (DBusGProxy *proxy, const GArray* IN_handles, GArray** OUT_arg1, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetHandleOwners", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handles, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg1, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners_reply) (DBusGProxy *proxy, GArray *OUT_arg1, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg1;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg1, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners_reply)data->cb) (proxy, OUT_arg1, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners_async (DBusGProxy *proxy, const GArray* IN_handles, org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetHandleOwners", org_freedesktop_Telepathy_Channel_Interface_Group_get_handle_owners_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_handles, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members (DBusGProxy *proxy, GArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetLocalPendingMembers", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members_reply) (DBusGProxy *proxy, GArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetLocalPendingMembers", org_freedesktop_Telepathy_Channel_Interface_Group_get_local_pending_members_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_members (DBusGProxy *proxy, GArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetMembers", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_members_reply) (DBusGProxy *proxy, GArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_members_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_members_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_members_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_Group_get_members_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetMembers", org_freedesktop_Telepathy_Channel_Interface_Group_get_members_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members (DBusGProxy *proxy, GArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetRemotePendingMembers", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members_reply) (DBusGProxy *proxy, GArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetRemotePendingMembers", org_freedesktop_Telepathy_Channel_Interface_Group_get_remote_pending_members_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle (DBusGProxy *proxy, guint* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetSelfHandle", error, G_TYPE_INVALID, G_TYPE_UINT, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle_reply) (DBusGProxy *proxy, guint OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  guint OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_UINT, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetSelfHandle", org_freedesktop_Telepathy_Channel_Interface_Group_get_self_handle_async_callback, stuff, g_free, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_Group */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_IceSignalling
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_IceSignalling

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers (DBusGProxy *proxy, GPtrArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetSessionHandlers", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_INVALID)), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_INVALID)), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetSessionHandlers", org_freedesktop_Telepathy_Channel_Interface_IceSignalling_get_session_handlers_async_callback, stuff, g_free, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_IceSignalling */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_ChatState
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_ChatState

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state (DBusGProxy *proxy, const guint IN_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "SetChatState", error, G_TYPE_UINT, IN_arg0, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state_async (DBusGProxy *proxy, const guint IN_arg0, org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "SetChatState", org_freedesktop_Telepathy_Channel_Interface_ChatState_set_chat_state_async_callback, stuff, g_free, G_TYPE_UINT, IN_arg0, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Interface_ChatState */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_StreamedMedia
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_StreamedMedia

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams (DBusGProxy *proxy, GPtrArray** OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "ListStreams", error, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ListStreams", org_freedesktop_Telepathy_Channel_Type_StreamedMedia_list_streams_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams (DBusGProxy *proxy, const guint IN_contact_handle, const GArray* IN_types, GPtrArray** OUT_arg2, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestStreams", error, G_TYPE_UINT, IN_contact_handle, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_types, G_TYPE_INVALID, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), OUT_arg2, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams_reply) (DBusGProxy *proxy, GPtrArray *OUT_arg2, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  GPtrArray* OUT_arg2;
  dbus_g_proxy_end_call (proxy, call, &error, dbus_g_type_get_collection ("GPtrArray", dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)), &OUT_arg2, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams_reply)data->cb) (proxy, OUT_arg2, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams_async (DBusGProxy *proxy, const guint IN_contact_handle, const GArray* IN_types, org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestStreams", org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_streams_async_callback, stuff, g_free, G_TYPE_UINT, IN_contact_handle, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_types, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams (DBusGProxy *proxy, const GArray* IN_stream_list, GError **error)

{
  return dbus_g_proxy_call (proxy, "RemoveStreams", error, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_stream_list, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams_async (DBusGProxy *proxy, const GArray* IN_stream_list, org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RemoveStreams", org_freedesktop_Telepathy_Channel_Type_StreamedMedia_remove_streams_async_callback, stuff, g_free, dbus_g_type_get_collection ("GArray", G_TYPE_UINT), IN_stream_list, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction (DBusGProxy *proxy, const guint IN_stream_id, const guint IN_stream_direction, GError **error)

{
  return dbus_g_proxy_call (proxy, "RequestStreamDirection", error, G_TYPE_UINT, IN_stream_id, G_TYPE_UINT, IN_stream_direction, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction_async (DBusGProxy *proxy, const guint IN_stream_id, const guint IN_stream_direction, org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "RequestStreamDirection", org_freedesktop_Telepathy_Channel_Type_StreamedMedia_request_stream_direction_async_callback, stuff, g_free, G_TYPE_UINT, IN_stream_id, G_TYPE_UINT, IN_stream_direction, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_StreamedMedia */

#ifndef DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_RoomList
#define DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_RoomList

static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms (DBusGProxy *proxy, gboolean* OUT_arg0, GError **error)

{
  return dbus_g_proxy_call (proxy, "GetListingRooms", error, G_TYPE_INVALID, G_TYPE_BOOLEAN, OUT_arg0, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms_reply) (DBusGProxy *proxy, gboolean OUT_arg0, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  gboolean OUT_arg0;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_BOOLEAN, &OUT_arg0, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms_reply)data->cb) (proxy, OUT_arg0, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "GetListingRooms", org_freedesktop_Telepathy_Channel_Type_RoomList_get_listing_rooms_async_callback, stuff, g_free, G_TYPE_INVALID);
}
static
#ifdef G_HAVE_INLINE
inline
#endif
gboolean
org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms (DBusGProxy *proxy, GError **error)

{
  return dbus_g_proxy_call (proxy, "ListRooms", error, G_TYPE_INVALID, G_TYPE_INVALID);
}

typedef void (*org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms_reply) (DBusGProxy *proxy, GError *error, gpointer userdata);

static void
org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms_async_callback (DBusGProxy *proxy, DBusGProxyCall *call, void *user_data)
{
  DBusGAsyncData *data = (DBusGAsyncData*) user_data;
  GError *error = NULL;
  dbus_g_proxy_end_call (proxy, call, &error, G_TYPE_INVALID);
  (*(org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms_reply)data->cb) (proxy, error, data->userdata);
  return;
}

static
#ifdef G_HAVE_INLINE
inline
#endif
DBusGProxyCall*
org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms_async (DBusGProxy *proxy, org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms_reply callback, gpointer userdata)

{
  DBusGAsyncData *stuff;
  stuff = g_new (DBusGAsyncData, 1);
  stuff->cb = G_CALLBACK (callback);
  stuff->userdata = userdata;
  return dbus_g_proxy_begin_call (proxy, "ListRooms", org_freedesktop_Telepathy_Channel_Type_RoomList_list_rooms_async_callback, stuff, g_free, G_TYPE_INVALID);
}
#endif /* defined DBUS_GLIB_CLIENT_WRAPPERS_org_freedesktop_Telepathy_Channel_Type_RoomList */

G_END_DECLS
