/*
 * Tapioca library
 * Copyright (C) 2006 INdT.
 * @author Luiz Augusto von Dentz <luiz.dentz@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TPA_CLIENT_H__
#define __TPA_CLIENT_H__

#include <tapioca/client/tpa-manager-factory.h>
#include <tapioca/client/tpa-manager.h>
#include <tapioca/client/tpa-connection.h>
#include <tapioca/client/tpa-stream-channel.h>
#include <tapioca/client/tpa-text-channel.h>
#include <tapioca/client/tpa-thread.h>
#include <tapioca/client/tpa-stream.h>
#include <tapioca/client/tpa-audio-stream.h>
#include <tapioca/client/tpa-video-stream.h>


#define tpa_client_init(b) \
        (tpa_thread_init(b))
#define tpa_client_shutdown(b) \
        (tpa_thread_shutdown(b))

#endif /* #ifndef __TPA_CLIENT_H__*/
